/*
 * This file is part of IFM (Interactive Fiction Mapper), copyright (C)
 * Glenn Hutchings 1997-2015.
 *
 * IFM comes with ABSOLUTELY NO WARRANTY.  This is free software, and you
 * are welcome to redistribute it under certain conditions; see the file
 * COPYING for details.
 */

/* User include file */

#ifndef VARS_H
#define VARS_H

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>

/* Configuration */
#include <vars-config.h>

/* Object types */
#include <vars-buffer.h>
#include <vars-graph.h>
#include <vars-hash.h>
#include <vars-list.h>
#include <vars-queue.h>
#include <vars-scalar.h>

/* Other stuff */
#include <vars-copy.h>
#include <vars-destroy.h>
#include <vars-getopt.h>
#include <vars-iterate.h>
#include <vars-macros.h>
#include <vars-memory.h>
#include <vars-system.h>
#include <vars-traverse.h>
#include <vars-type.h>
#include <vars-write.h>
#include <vars-utils.h>

#endif
